require "test_helper"

class MethodsTest < MiniTest::Test
  def test_fibo_finder
    assert_equal 0, Sungemm.fibo_finder(0)
    assert_equal 1, Sungemm.fibo_finder(1)
    assert_equal 3, Sungemm.fibo_finder(4)
    assert_equal 13, Sungemm.fibo_finder(7)
    assert_equal 55, Sungemm.fibo_finder(10)
  end

  def test_longest_palindrome
    assert_equal "yzzy", Sungemm.longest_palindrome("xyzzy")
    assert_equal "dhfdkjfffhhfffjkdfhd", Sungemm.longest_palindrome("afbbbfj"\
      "djklgdfdhfdkjfffhhfffjkdfhdhkyejejfjkd")
    assert_equal "racecar", Sungemm.longest_palindrome("bartarcarracecarbart"\
      "ar")
    assert_equal "46264", Sungemm.longest_palindrome("3.14159265358979323846"\
      "264338327950288419716939937510582097494459230781640628620899862803482"\
      "5342117067982")
  end

  def test_count
    test = %w(cat dog fish fish)
    assert_equal ({ 'cat' => 1, 'dog' => 1, 'fish' => 2 }), Sungemm.count(test)
  end

  def test_even_sum
    arr = ["cat", "dog", "bird", "fish"]
    assert_equal ["drib", "hsif"], Sungemm.even_sum(arr)
    arr = ["why", "chunky", nil, "lucky", "stiff"]
    assert_equal ["yknuhc"], Sungemm.even_sum(arr)
    arr = ["rewsna", "hitch hiker", "si", "guide", "galaxies ", "24"]
    assert_equal ["answer", "is", "42"], Sungemm.even_sum(arr)
  end

  def test_join_params
    url_params = {
      'first_param'  => 123,
      'second_param' => 456,
      'third_param'  => 678
    }
    url = 'http://www.foobar.com'
    test_url = 'http://www.foobar.com?'\
               'first_param=123&second_param=456&third_param=678'
    assert_equal test_url, Sungemm.join_params(url, url_params)
  end

  def test_pretty_date
    assert_equal "Nov 30, 1835", Sungemm.pretty_date("11-30-1835")
    assert_equal "Jul 20, 1933", Sungemm.pretty_date("July 20, 1933")
    assert_equal "Nov 11, 1922", Sungemm.pretty_date("1922-11-11")
    assert_equal "Sep 20, 1978", Sungemm.pretty_date("9/20/1978")
  end

  def test_random_boolean
    array = []

    100.times do
      array << :dummy if Sungemm.random_boolean
    end

    assert_equal true, (1..100) === array.size
    assert_equal true, array.size != 100
  end

  def test_separate_with_comma
    assert_equal "1", Sungemm.separate_with_comma(1)
    assert_equal "10", Sungemm.separate_with_comma(10)
    assert_equal "100", Sungemm.separate_with_comma(100)
    assert_equal "1,000", Sungemm.separate_with_comma(1000)
    assert_equal "10,000", Sungemm.separate_with_comma(10000)
    assert_equal "100,000", Sungemm.separate_with_comma(100000)
    assert_equal "1,000,000", Sungemm.separate_with_comma(1000000)
  end

  def test_simple_sub
    str = "?? == ??"

    assert_equal "?? <= ??", Sungemm.simple_sub(str, "==", "<=")
    assert_equal "?? == ??", Sungemm.simple_sub(str, "abc", "def")
    assert_equal "fun?? == fun??", Sungemm.simple_sub(str, "??", "fun??")
    naruse_answer = "Date.parse(date.sub(/(\d+)[-\/](\d\d)."\
                    "(\d{4})/,'\\3-\\1-\\2')).strftime('%b %d, %Y')"
    right_answer = "#{naruse_answer} == #{naruse_answer}"
    assert_equal right_answer, Sungemm.simple_sub(str, "??", naruse_answer)
  end
end
